function [ floats, indices ] = find( p_nemo_data, p_float_number )
%FIND Returns the float with the given p_float_number.
%   Searches for the given float in p_nemo_struct.
%
%   Parameters:
%   p_nemo_data:        The nemo data to be searched.
%   p_float_number:     The float number that is being searched for.
%                       It can also be a 1D vector of float numbers.
%
%   Returns:
%   float:              Copy from p_nemo_data of the float with the given
%                       float number.
%   index:              The index of the float in p_nemo_data.

%index = cellfun(@(x) x{1}.FLOAT_IDENTIFICATION.float_serial_number == p_float_number, p_nemo_data);

indices = [];
floats = {};

float_number_length = length(p_float_number);
for current_float_number = 1:float_number_length
    index = cellfun(@(x) find_float(x), p_nemo_data);
    if (~any(index))
        continue;
    elseif (sum(index) > 1)
        disp(['Multiple floats found: ' index]);
        return
    end

    indices = [indices find(index)];
    floats{end + 1} = p_nemo_data{index};
    

end

if (length(p_float_number) == 1)
    floats = floats{1};
end

    function [ is_float ] = find_float(p_float)
        if isfield(p_float, 'GENERAL_INFO')
            is_float = p_float.GENERAL_INFO.SERIAL == p_float_number(current_float_number);
        else
            is_float = p_float{1}.FLOAT_IDENTIFICATION.float_serial_number == p_float_number(current_float_number);
        end
    end

end

