function [ boolean ] = save_startup_message( p_startup_messages, p_filepath, p_overwrite )
%SAVE_STARTUP_MESSAGES Summary of this function goes here
%   Detailed explanation goes here

%% Initialize variables
boolean = false;

%% Parameter check
parameter_error = false;

if (~iscell(p_startup_messages) || ~ischar(p_filepath))
    parameter_error = true;
end

if (~exist('p_overwrite', 'var') || isempty(p_overwrite))
    p_overwrite = 1; % default setting is to overwrite existing profile files
end

if (parameter_error) % display error message
    disp([ mfilename ': Wrong parameter! Please check your input parameters carefully!']);
    return;
else % do some cleanup
    clear parameter_error;
end

%% File existence checks

if ~exist(p_filepath, 'dir')
    mkdir(p_filepath);
end

%% Configuration parameters
double_format = '%.15g';
help_tabs = ['\t', '\t', '\t', '\t', '\t', '\t', '\t', '\t', '\t', '\t', '\t', '\t'];
desired_tab_count = 12;


%% Write message to file

%for outer = 1:length(p_startup_messages) % required if there are multiple messages
current_message = p_startup_messages{end};
filename = [ ...
    p_filepath ...
    sprintf('%04d', current_message.float_serial_number) ...
    '.startup_message' ...
    ];

if exist(filename, 'file') == 2 && ~p_overwrite
    % file will not be overwritten
    boolean = true;
    return
end

of_id = fopen(filename, 'w'); % open file for writing
fprintf(of_id, '[STARTUP_MESSAGE]\n');
write_struct(current_message);
fclose(of_id);

boolean = true;
%end

    function [ tabs ] = get_tabs_to_insert(p_member_name)
        % this function computes the required tabs to insert, making the
        % textfile easier to read.
        tablength = 4;
        tab_count = desired_tab_count - floor((length(p_member_name)+1)/tablength);
        tabs = help_tabs(1:(tab_count*2));
    end

    function write_struct(p_input_struct)
        % get all fieldnames and write them to the file
        member_names = fieldnames(p_input_struct);
        member_count = length(member_names);
        for o_member = 1:member_count % run through all members
            % calculate how many tabs have to be inserted to have a
            % good table layout
            tabstring = get_tabs_to_insert(member_names{o_member});
            fprintf(of_id, ['-' member_names{o_member} tabstring]);
            current_member = p_input_struct.(member_names{o_member});
            current_member_class = class(current_member);
            switch current_member_class
                case {'double', 'logical'}
                    write_double(current_member);
                case 'char'
                    fprintf(of_id, [current_member '\n']);
                otherwise
                    disp(['Unknown class in file: ' class(current_member)]);
            end
            
        end
        clear o_member
    end

    function write_double(p_input_double)
        
        for o_double = 1:size(p_input_double, 1)
            if length(p_input_double(o_double, :)) > 1
                fprintf(of_id, sprintf([double_format '\t'], p_input_double(o_double, 1:end-1)));
            end
            fprintf(of_id, [double_format '\n'], p_input_double(o_double, end));
        end
        clear o_double
        
    end

end

