function [ float_data ] = single_float( p_path, p_folder_separator, p_files_to_exclude )
%SINGLE_FLOAT Loads a float from the harddisk.
%   Loads all profiles of a float in the given path.
%
%   Parameters:
%   p_path:             The filepath where the .profile files are stored.
%   p_folder_separator: The folder separator character.
%   p_files_to_exclude: List of files that will be ignored.
%
%   Returns:
%   float_data:         The loaded profiles.

%% Initialize return variable
float_data = {};

%% Get all files in the folder and load profiles
if (~exist('p_folder_separator', 'var'))
    p_folder_separator = '\';
end
current_files = dir(fullfile([p_path p_folder_separator], '*.profile'));
if (exist('p_files_to_exclude', 'var'))
    current_files = exclude_elements(current_files, p_files_to_exclude, 'dir');
end

profile_count = length(current_files);

if (profile_count > 0)
    float_data = {};

    for o_profile_index = 1:profile_count
        % read current profile
        profile = nemo.profile.load(fullfile([p_path p_folder_separator], current_files(o_profile_index).name));
        float_data{o_profile_index} = profile;
        clear profile;
    end

end

end

