function [ boolean ] = rafos( p_nemo_data, p_config )
%RAFOS Plots the RAFOS data. of the given nemo floats.
%   
%   Parameters:
%   p_nemo_data:        The nemo data which will be plotted.
%   p_config:           The nemo configuration.
%   
%   Returns:
%   boolean:            True if successful.

%% Initialize return variable
boolean = false;

%% Parameter check %TODO

%% Get config parameter
% get plot details
width = p_config.PLOT_RAFOS.image_width;
height = p_config.PLOT_RAFOS.image_height;
paperunit = p_config.PLOT_RAFOS.image_paperunit;
image_type = p_config.PLOT_RAFOS.image_type;
directory = fullfile(p_config.GENERAL.storage_directory_plots, p_config.PLOT_RAFOS.storage_directory_image);
directory_fig = fullfile(p_config.GENERAL.storage_directory_plots, p_config.PLOT_RAFOS.storage_directory_fig);
ylabel_fontsize = p_config.PLOT_RAFOS.ylabel_fontsize;
xlabel_fontsize = p_config.PLOT_RAFOS.xlabel_fontsize;
axis_fontsize = p_config.PLOT_RAFOS.axis_fontsize;
title_fontsize = p_config.PLOT_RAFOS.title_fontsize;

if (~isdir(directory))
    mkdir(directory);
end
if ~exist(directory_fig, 'dir')
    mkdir(directory_fig);
end

%% Collect required data

switch (class(p_nemo_data{1}))
    case 'struct' % only one float is to be processed
        rafos_names = p_nemo_data{1}.RAFOS_VALUES_FORMAT;
        boolean = plot_float(p_nemo_data);
    case 'cell' % more than one float has to be processed
        rafos_names = p_nemo_data{1}{1}.RAFOS_VALUES_FORMAT;
        boolean = all(cellfun(@plot_float, p_nemo_data));
    otherwise
        disp([mfilename ': Class ' class(p_nemo_data{1}) ' not supported for plotting!']);
end

    function boolean = plot_float(p_float)
        boolean = false;
        rafos_data = nemo.float.collect(p_float, 'RAFOS_VALUES', '', 'combine');
        
        if (isempty(rafos_data))
            boolean = true;
            return
        end
        
        
        plot_c = [];
        plot_y = [];
        plot_x = [];
        plot_status = [];
        for i = 8:2:18
            rafos_correlation = rafos_data(:, i);
            
            plot_c = [plot_c; rafos_correlation];
            plot_y = [plot_y; rafos_data(:, i + 1)];
            plot_x = [plot_x; datenum(rafos_data(:, 2:7))];
            plot_status = [plot_status; rafos_data(:, 1)];
        end

        % sort rows by color
        sorted_plot = [plot_x, plot_y, plot_c];
        sorted_plot = flipud(sortrows(sorted_plot, 3));
        plot_x = sorted_plot(:, 1);
        plot_y = sorted_plot(:, 2);
        plot_c = sorted_plot(:, 3);
        clear sorted_plot;
        
        
        % initialize figure
        figure_id = figure('Visible', 'off'); % create figure
        %figure_id = figure(); % create figure
        set(figure_id,'InvertHardcopy','on');
        set(figure_id,'PaperUnits', paperunit);
        papersize = get(figure_id, 'PaperSize');
        left = (papersize(1)- width)/2;
        bottom = (papersize(2)- height)/2;
        myfiguresize = [left, bottom, width, height];
        set(figure_id,'PaperPosition', myfiguresize);
        
        % plot data
        sub(1) = subplot(5, 1, 1:4); % travel time
        hold on
        box on
        grid on
        % get required information about x-axis limits and ticks
        x_diff = max(plot_x) - min(plot_x);
        set(gca, 'XLimMode', 'manual', 'XLim', [min(plot_x), max(plot_x)]);
        if (x_diff < 30)
            set(gca, 'XTick', [min(plot_x):5:max(plot_x)]);
        elseif (x_diff < 365)
            set(gca, 'XTick', [min(plot_x):30:max(plot_x)]);
        else
            set(gca, 'XTick', [min(plot_x):365:max(plot_x)]);
        end
        
        s = scatter3(plot_x, plot_y, plot_c, 12, plot_c, 'filled');
        view(0, 90);
        c = colorbar;
        caxis([0 255]);
        colormap(flipud(colormap));
        c.Label.String = 'Correlation Height (ch)';
        
        ylim(p_config.PLOT_RAFOS.ylim);
        ylabel('RAFOS Time of Arrival [s]', 'FontSize', ylabel_fontsize);
%         xlabel('Date of profile', 'FontSize', xlabel_fontsize);
        if (p_float{1}.SECOND_ORDER_INFORMATION.best_guess_position_lat > 0)
            deployment_string = ' (Arctic)';
        else
            deployment_string = ' (Antarctica)';
        end
        title(sub(1), [ 'Float ' ...
               num2str(p_float{1}.FLOAT_IDENTIFICATION.float_serial_number) ...
               ' @ ' ...
               datestr(datetime('now', 'Format', 'dd-MMM-yyyy HH:mm:SS')) ...
               deployment_string ...
             ], 'FontSize', title_fontsize);
        datetick('x','yyyy-mm-dd', 'keepticks', 'keeplimits');
        set(gca, 'fontsize', axis_fontsize)
        clear s
        hold off
        
        
        sub(2) = subplot(5, 1, 5); % rafos status
        hold on
        box on
        grid on
        % get required information about x-axis limits and ticks
        x_diff = max(plot_x) - min(plot_x);
        set(gca, 'XLimMode', 'manual', 'XLim', [min(plot_x), max(plot_x)]);
        if (x_diff < 30)
            set(gca, 'XTick', [min(plot_x):5:max(plot_x)]);
        elseif (x_diff < 365)
            set(gca, 'XTick', [min(plot_x):30:max(plot_x)]);
        else
            set(gca, 'XTick', [min(plot_x):365:max(plot_x)]);
        end
        set(gca, 'YTickMode', 'manual', 'YLimMode', 'manual', ...
            'YTick', [0:2:10], 'YLim', [0, 10]);
        
        s = stairs(datenum(rafos_data(:, 2:7)), rafos_data(:, 1), ...
            'Marker', 'o');
        s.DisplayName = rafos_names{1};
        
        clear s
%         title(sub(2), 'RAFOS status', 'FontSize', p_config.PLOT_RAFOS.title_fontsize);
        datetick('x','yyyy-mm-dd', 'keepticks', 'keeplimits');
        ylim([0 8]);
        ylabel('Status', 'FontSize', ylabel_fontsize);
        xlabel('Date of profile', 'FontSize', xlabel_fontsize);
        set(gca, 'fontsize', axis_fontsize)
        clear a
        hold off
        
        print(figure_id, ...
         [directory p_config.PLOT_RAFOS.image_filename ...
           num2str(p_float{1}.FLOAT_IDENTIFICATION.float_serial_number)] ...
         , image_type);
     
        if (p_config.PLOT_RAFOS.save_figure)
            set(gcf,'CreateFcn','set(gcf,''Visible'',''on'')');
            saveas(figure_id, ...
                [directory_fig ...
                 p_config.PLOT_RAFOS.figure_filename ...
                 num2str(p_float{1}.FLOAT_IDENTIFICATION.float_serial_number)]);
        end
     
        close(figure_id);
        boolean = true;
    end



end

