function [ extended_nemo_data ] = add_software_profile_times2rtc( p_nemo_data )
%ADD_SOFTWARE_PROFILE_TIMES_IN_RTC Summary of this function goes here
%   Detailed explanation goes here

%% Parameter check
if ~iscell(p_nemo_data)
    disp([mfilename ': Please check your input parameter!']);
end

%% Variables to convert
variable_names_to_convert = { ...
    'xmit_descent_start_time', ...
    'xmit_parking_start_time', ...
    'xmit_upcast_start_time', ...
    'xmit_ascent_end_time', ...
    'xmit_surface_start_time' ...
};

%% Calculate datevec

extended_nemo_data = cellfun(@(x) extend_float(x), p_nemo_data, 'UniformOutput', false);

    function [ extended_float ] = extend_float(p_float)
        extended_float = cellfun(@(x) extend_profile(x), p_float, 'UniformOutput', false);
    end

    function [ extended_profile ] = extend_profile(p_profile)
        
        extended_profile = p_profile;
        if isempty(p_profile)
            return
        end
        if ~isfield(extended_profile, 'SECOND_ORDER_INFORMATION')
            extended_profile.SECOND_ORDER_INFORMATION = struct();
        end
        
        % initialize variables
        for i = 1:length(variable_names_to_convert)
            extended_profile.SECOND_ORDER_INFORMATION.(variable_names_to_convert{i}) = NaN(1, 6);
        end
        extended_profile.SECOND_ORDER_INFORMATION.xmit_ascent_start_time = NaN(1, 6);
        
        % calculate software <-> rtc correction
        % xmit_ascent_start_time + 10s = RTC @ 2000m
        [rtc_datevec, software_datevec] = find_rtc_datevec(p_profile);
        extended_profile.SECOND_ORDER_INFORMATION.xmit_ascent_start_time = datevec(datetime(rtc_datevec) - seconds(10));
        
        drift_rtc_software = etime(rtc_datevec, software_datevec) + 10;
        for i = 1:length(variable_names_to_convert)
            extended_profile.SECOND_ORDER_INFORMATION.(variable_names_to_convert{i}) = ...
                datevec(datetime([ ...
                    fliplr(extended_profile.OVERALL_MISSION_INFORMATION.start_date), ...
                    extended_profile.OVERALL_MISSION_INFORMATION.start_time 0 ...
                ]) ...
                + seconds(extended_profile.PROFILE_TECHNICAL_DATA.(variable_names_to_convert{i})) ...
                + seconds(drift_rtc_software));
                
        end
        extended_profile.SECOND_ORDER_INFORMATION.difference_rtc_software = drift_rtc_software;
        
        
    end

    function [ rtc_datevec, software_datevec ] = find_rtc_datevec(profile)
        software_datevec = ...
            datevec( ...
                datetime([ ...
                    fliplr(profile.OVERALL_MISSION_INFORMATION.start_date), ...
                    profile.OVERALL_MISSION_INFORMATION.start_time 0 ...
                ]) ...
                + seconds(profile.PROFILE_TECHNICAL_DATA.xmit_ascent_start_time) ...
        );
        software_time = software_datevec(4:6);
        % get internal clock (RTC) @ 2000m
        rtc_time = profile.PROFILE_DATA( ...
            profile.PROFILE_DATA(:, 7) == max(profile.PROFILE_DATA(:, 7)), ...
            2:4);
        % if there are multiple pressure levels get the one with the
        % earliest time
        rtc_time = sortrows(rtc_time, [1:3]);
        if isempty(rtc_time) || isempty(software_datevec) % prevent errors if empty
            rtc_datevec = NaN(1, 6);
            software_datevec = NaN(1, 6);
           return;
        end
        rtc_time = rtc_time(end, :);
        
        rtc_datevec = datevec(datetime([software_datevec(1:3), rtc_time]));
        
        if (any(rtc_time(1) == 21:23) && any(software_time(1) == 0:3))
            % RTC is more trustworthy, so reduce the software date by 1
            rtc_datevec = datevec(datetime([software_datevec(1:3), rtc_time]) - days(1));
        elseif (any(rtc_time(1) == 0:3) && any(software_time(1) == 21:23))
            % same here, but now add 1 day
            rtc_datevec = datevec(datetime([software_datevec(1:3), rtc_time]) + days(1));
        end
    end

end

