function [ commented_nemo_data ] = quality_check( p_nemo_data )
%QUALITY_CHECK Does several quality checks.
%   1) Adds two fields to the SECOND_ORDER_INFORMATION block:
%       fieldname                           values
%       xmit_transmittion_type          nrt, delayed, unknown
%       ice_detected                        0, 1
%
%	2) Removes profiles where the best_guess_datevec is before the
%	   deployment time.
%
%   Parameters:
%   p_nemo_data:            The nemo data.
%
%   Returns:
%   commented_nemo_data:    The nemo data with applied changes.

%% Check passed parameter
parameter_error = false;

if (~iscell(p_nemo_data))
    parameter_error = true;
end

if (parameter_error)
    disp([mfilename ': Parameter error. Please check your input parameters.']);
end
clear parameter_error;

float_count = length(p_nemo_data);
commented_nemo_data = p_nemo_data;

for o_float = 1:float_count
    
    profile_count = length(commented_nemo_data{o_float});
    current_float = commented_nemo_data{o_float};
    
    for o_profile_index = 1:profile_count % process all profiles
        
        %% Check if profile has been sent directly after recording
        
        if (o_profile_index < profile_count ...
                && ~nemo.profile.verify_iridium( ...
                current_float{o_profile_index}, ...
                current_float{o_profile_index + 1}) ...
            )
        
          switch (nemo.profile.get_status(current_float{o_profile_index}))
              case 'DONE'
                  % it has been sent later on, no clue why
                  current_float{o_profile_index}.SECOND_ORDER_INFORMATION.xmit_transmission_type = 'delayed';
                  current_float{o_profile_index}.SECOND_ORDER_INFORMATION.ice_detected = 0;
              case 'ICE DETECTION'
                  current_float{o_profile_index}.SECOND_ORDER_INFORMATION.xmit_transmission_type = 'delayed';
                  current_float{o_profile_index}.SECOND_ORDER_INFORMATION.ice_detected = 1;
              otherwise
                  current_float{o_profile_index}.SECOND_ORDER_INFORMATION.xmit_transmission_type = 'unknown';
                  current_float{o_profile_index}.SECOND_ORDER_INFORMATION.ice_detected = 0;
          end
        else
            current_float{o_profile_index}.SECOND_ORDER_INFORMATION.xmit_transmission_type = 'nrt';
            switch (nemo.profile.get_status(current_float{o_profile_index}))
              case 'DONE'
                  current_float{o_profile_index}.SECOND_ORDER_INFORMATION.ice_detected = 0;
              case 'ICE DETECTION'
                  current_float{o_profile_index}.SECOND_ORDER_INFORMATION.ice_detected = 1;
                otherwise
                  current_float{o_profile_index}.SECOND_ORDER_INFORMATION.ice_detected = 0;
          end
        end
        
        %% Check if profile time is before deployment time
        deploy_datenum = datenum([ ...
                           fliplr(current_float{o_profile_index}.DEPLOYMENT_INFO.deployment_date), ...
                           current_float{o_profile_index}.DEPLOYMENT_INFO.deployment_time, ...
                           0 ...
                         ]);
        profile_datenum = datenum(current_float{o_profile_index}.SECOND_ORDER_INFORMATION.best_guess_datevec);
        if (profile_datenum < deploy_datenum)
            disp(['Removed profile ' num2str(current_float{o_profile_index}.PROFILE_TECHNICAL_DATA.xmit_profile_number) ...
                  ' of float ' num2str(current_float{o_profile_index}.FLOAT_IDENTIFICATION.float_serial_number) ...
                  ' because it was recorded before deployment!']);
            current_float{o_profile_index} = {};
        end
        
%         if (nemo.profile.positions_differ_by(commented_nemo_data{o_profile_index}, 50))
%             commented_nemo_data{o_profile_index}.COMMENT.position = 'gps and iridium differ by more than 50km';
%         end

    end
    
    %% Remove all empty profiles
    current_float = current_float(~cellfun(@(x) isempty(x), current_float));
    
    %% Save current float
    commented_nemo_data{o_float} = current_float;
end

%% Manual quality checks


%% Remove all empty floats
commented_nemo_data = commented_nemo_data(~cellfun(@(x) isempty(x), commented_nemo_data));

end

