function [ boolean ] = verify_iridium( p_profile, p_next_profile )
%VERIFY_IRIDIUM Checks if the Iridium data represents profile time and position.
%
%   Returns: True if Iridium time of current profile is smaller than the
%            one of the next profile.
%
%   Parameters:
%   p_profile:          The current nemo profile.
%   p_next_profile:     The nemo profile with profile no +1.

%% Initializing return variables
boolean = false;

%% Parameter check

if (~isstruct(p_profile) || ~isstruct(p_next_profile))
    disp([mfilename ': Wrong parameters. Please check your input. Returning false!']);
    return
end

%% Check if iridium section is available
if (~isfield(p_profile, 'IRIDIUM_DATA') || ~isfield(p_next_profile, 'IRIDIUM_DATA'))
    boolean = false;
    return
else % compare it to next profile
    % the current profile datetime has to be lower than the one of the next
    % profile
    boolean = ( ...
        datenum(p_profile.IRIDIUM_DATA(4:9)) ...
        < ...
        datenum(p_next_profile.IRIDIUM_DATA(4:9)) ...
    );
    
end

return;

end