function [ float_metadata ] = find_float_in_metadata( p_metadata, p_imeis )
%FIND_FLOAT_IN_METADATA Returns the metadata of the given IMEI
%   Searches p_metadata for the given IMEI.
%
%   Parameters:
%   p_metadata:                 The metadata of the floats.
%   p_imeis:                    The IMEI(s) to be searched for.
%
%   Returns:
%   float_metadata:             False if not found. Returns copies of the float
%                               metadata of the given IMEIs otherwise.

%% Initialize return value
float_metadata = false;

%% Find the float

if (isempty(p_imeis))
    return;
end
booleans = cellfun(@(x) x.GENERAL_INFO.IMEI == p_imeis(1), p_metadata);
for i=2:length(p_imeis)
    tmp_booleans = cellfun(@(x) x.GENERAL_INFO.IMEI == p_imeis(i), p_metadata);
    booleans = booleans + tmp_booleans;
end

booleans(booleans > 1) = 1;
booleans = logical(booleans);

float_metadata = p_metadata(booleans);

if (~isempty(float_metadata))
    return
end

% nothing has been found, so check all serials

booleans = cellfun(@(x) x.GENERAL_INFO.SERIAL == p_imeis(1), p_metadata);
for i=2:length(p_imeis)
    tmp_booleans = cellfun(@(x) x.GENERAL_INFO.SERIAL == p_imeis(i), p_metadata);
    booleans = booleans + tmp_booleans;
end

booleans(booleans > 1) = 1;
booleans = logical(booleans);

float_metadata = p_metadata(booleans);

end

